@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "el-fetch" "20250105.2335"
+(define-package "el-fetch" "20251225.1426"
   "Show system information in Neofetch-like style (eg CPU, RAM)."
   '((emacs "25.1"))
-  :url "https://gitlab.com/xgqt/emacs-el-fetch"
-  :commit "a1ae3704de96e6d622a67faacfae7a5993f96699"
-  :revdesc "a1ae3704de96"
+  :url "https://gitlab.com/xgqt/xgqt-elisp-app-el-fetch"
+  :commit "169e2bffe77b43577acbf83d7d8073b6808b880e"
+  :revdesc "169e2bffe77b"
   :keywords '("games")
   :authors '(("Maciej Barć" . "xgqt@xgqt.org"))
   :maintainers '(("Maciej Barć" . "xgqt@xgqt.org")))
